import 'package:deposits_ui_kit/deposits_ui_kit.dart';
import 'package:flutter/material.dart';
import 'package:widgetbook/widgetbook.dart';

final Key bottomSheetKey = UniqueKey();
final Key contentKey = UniqueKey();
final DepBottomSheetController _controller = DepBottomSheetController();

WidgetbookUseCase basicBottomSheet(BuildContext context) {
  return WidgetbookUseCase(
      name: 'BottomSheet/Basic',
      builder: (context) {
        void showDefaultModal(context) {
          showModalBottomSheet(
              context: context,
              shape: const RoundedRectangleBorder(
                borderRadius: BorderRadius.vertical(
                  top: Radius.circular(15),
                ),
              ),
              clipBehavior: Clip.antiAliasWithSaveLayer,
              builder: (context) {
                return Container(
                  padding:
                      const EdgeInsets.symmetric(horizontal: 20, vertical: 10),
                  height: 300,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      verticalSpaceSmall,
                      verticalSpaceTiny,
                      Visibility(
                        visible: context.knobs
                            .boolean(label: 'Show Handle', initialValue: true),
                        child: Align(
                          alignment: Alignment.center,
                          child: SizedBox(
                            height: 3,
                            width: 50,
                            child: Container(
                              color: gray300,
                            ),
                          ),
                        ),
                      ),
                      verticalSpaceSmall,
                      verticalSpaceSmall,
                      Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          // first item
                          Row(
                            children: [
                              Visibility(
                                visible: context.knobs.boolean(
                                    label: 'Show bck button',
                                    initialValue: true),
                                child: const Icon(
                                  Icons.arrow_back_ios,
                                  color: secondaryColor,
                                ),
                              ),
                              Visibility(
                                visible: context.knobs.boolean(
                                    label: 'Show left title',
                                    initialValue: true),
                                child: DepText(
                                  text: 'Left Title',
                                  txtColor: const Color(0xFF0D7FE9),
                                  font: 17,
                                  fontFamily:
                                      preferedFont(DepFontName.sfproText),
                                  fntweight: FontWeight.w400,
                                ),
                              ),
                            ],
                          ),
                          // second item
                          DepText(
                            text: 'Title',
                            txtAlign: TextAlign.center,
                            txtColor: const Color(0xFF2A2E33),
                            font: 17,
                            fontFamily: preferedFont(DepFontName.sfproText),
                            fntweight: FontWeight.w600,
                            letterSpace: -0.41,
                          ),
                          // third item
                          Visibility(
                            visible: context.knobs.boolean(
                                label: 'Show dismissable Icon',
                                initialValue: true),
                            child: Container(
                              width: 30,
                              height: 30,
                              decoration: ShapeDecoration(
                                color: gray200,
                                shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(100),
                                ),
                              ),
                              alignment: Alignment.center,
                              child: const Icon(
                                Icons.close,
                                color: gray500,
                              ),
                            ),
                          )
                        ],
                      ),
                      verticalSpaceMedium,
                      DepText(
                        text:
                            'Here’s a title that can be used and can span multiple lines.',
                        txtAlign: TextAlign.center,
                        txtColor: gray700,
                        font: 15,
                        fontFamily: preferedFont(DepFontName.sfproText),
                        fntweight: FontWeight.w400,
                      ),
                    ],
                  ),
                );
              });
        }

        return Scaffold(
          appBar: DepAppbarWidget(
            titleWidget: const DepText(
              text: "Basic Bottom Sheet",
              txtColor: Colors.white,
              font: 18,
            ),
            addBackButton: false,
            addCloseButton: false,
            backgroundColor: primaryColor,
          ),
          body: Container(
              alignment: Alignment.center,
              padding: const EdgeInsets.symmetric(
                horizontal: 16,
              ),
              child: Center(
                child: DepButton(
                    title: 'Sample Bottom Sheet',
                    onPressed: () {
                      showDefaultModal(context);
                    },
                    textColor: white),
              )),
        );
      });
}
