import 'package:deposits_ui_kit/deposits_ui_kit.dart';
import 'package:flutter/material.dart';

class DepPaymentCard extends StatelessWidget {
  final String cardName, cardAmount, cardNumber, cardExpiry, cardCVV;
  final Widget cardType, brand;
  final bool isHideCardInfo;
  final Color cardColor;
  const DepPaymentCard(
      {super.key,
      required this.cardName,
      required this.cardAmount,
      required this.cardNumber,
      required this.cardExpiry,
      required this.cardCVV,
      required this.cardType,
      required this.cardColor,
      required this.isHideCardInfo,
      required this.brand});

  @override
  Widget build(BuildContext context) {
    return //card
        Container(
      // height: 215.04,
      padding: const EdgeInsets.symmetric(vertical: 20),
      decoration: ShapeDecoration(
        gradient: LinearGradient(
          begin: const Alignment(0.93, -0.38),
          end: const Alignment(-0.93, 0.38),
          colors: [cardColor, cardColor],
        ),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(18),
        ),
      ),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          //name and logo
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                DepText(
                  text: cardName.toUpperCase(),
                  txtColor: gray500,
                  font: 14,
                  fntweight: FontWeight.w400,
                  fontFamily: preferedFont(DepFontName.circularStd),
                ),
                SizedBox(
                  width: 85,
                  child: brand,
                ),
              ],
            ),
          ),
          verticalSpaceMediumX,
          //card amount
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 20),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    DepText(
                      text: isHideCardInfo == true ? '\$****' : cardAmount,
                      txtColor:
                          cardColor == gray700 ? Colors.white : Colors.black,
                      font: 26,
                      fntweight: FontWeight.w500,
                      fontFamily: preferedFont(DepFontName.sfproDisplay),
                    ),
                    DepText(
                      text: 'Available balance',
                      txtColor: gray500,
                      font: 12,
                      fntweight: FontWeight.w400,
                      fontFamily: preferedFont(DepFontName.circularStd),
                    )
                  ],
                ),
              ],
            ),
          ),
          verticalSpaceMediumX,
          //cvv, exp, card number
          Container(
            decoration: BoxDecoration(
              border: Border(
                top: BorderSide(
                  color: white
                      .withOpacity(0.1), // You can set the color of the line
                  width: 1.0, // You can set the width of the line
                ),
              ),
            ),
            child: Padding(
              padding: const EdgeInsets.only(left: 20, right: 20, top: 12),
              child: Row(
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      DepText(
                        text: 'Card number',
                        txtColor: gray500,
                        font: 12,
                        fontFamily: preferedFont(DepFontName.circularStd),
                        fntweight: FontWeight.w400,
                      ),
                      DepText(
                        text: isHideCardInfo == true
                            ? formatCardNumber(cardNumber)
                            : cardNumber,
                        txtColor:
                            cardColor == gray700 ? Colors.white : Colors.black,
                        font: 14,
                        fntweight: FontWeight.w400,
                        fontFamily: preferedFont(DepFontName.circularStd),
                      ),
                    ],
                  ),
                  horizontalSpaceSmallY,
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      DepText(
                        text: 'EXP',
                        txtColor: gray500,
                        font: 12,
                        fntweight: FontWeight.w400,
                        fontFamily: preferedFont(DepFontName.circularStd),
                      ),
                      DepText(
                        text: isHideCardInfo == true
                            ? formatExpiryDate(cardExpiry)
                            : cardExpiry,
                        txtColor:
                            cardColor == gray700 ? Colors.white : Colors.black,
                        font: 14,
                        fontFamily: preferedFont(DepFontName.circularStd),
                        fntweight: FontWeight.w400,
                      ),
                    ],
                  ),
                  horizontalSpaceSmallY,
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      DepText(
                        text: 'CVV',
                        txtColor: gray500,
                        font: 12,
                        fontFamily: preferedFont(DepFontName.circularStd),
                        fntweight: FontWeight.w400,
                      ),
                      DepText(
                        text: isHideCardInfo == true
                            ? formatCVV(cardCVV)
                            : cardCVV,
                        txtColor:
                            cardColor == gray700 ? Colors.white : Colors.black,
                        font: 14,
                        fontFamily: preferedFont(DepFontName.circularStd),
                        fntweight: FontWeight.w400,
                      ),
                    ],
                  ),
                  horizontalSpaceSmallY,
                  Expanded(
                      child: Container(
                          alignment: Alignment.center, child: cardType)),
                ],
              ),
            ),
          )
        ],
      ),
    );
  }
}

class DefaultDepPaymentCard extends StatelessWidget {
  final String cardName, cardNumber, cardExpiry, cardCVV;
  final Widget cardType;
  const DefaultDepPaymentCard(
      {super.key,
      required this.cardName,
      required this.cardNumber,
      required this.cardExpiry,
      required this.cardCVV,
      required this.cardType});

  @override
  Widget build(BuildContext context) {
    return //card
        Container(
      // width: 336,
      height: 215.04,
      decoration: ShapeDecoration(
        gradient: const LinearGradient(
          begin: Alignment(0.93, -0.38),
          end: Alignment(-0.93, 0.38),
          colors: [Color(0xFF0B258F), Color(0xFF2743B4)],
        ),
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(18),
        ),
      ),
      child: Stack(
        children: [
          Positioned(
            left: 247,
            top: 168,
            right: 17,
            child: SizedBox(width: 85, height: 30, child: cardType),
          ),
          Positioned(
            left: 17,
            top: 129,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Column(
                  mainAxisSize: MainAxisSize.min,
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(
                      cardNumber,
                      style: const TextStyle(
                        color: Colors.white,
                        fontSize: 16,
                        fontWeight: FontWeight.w400,
                      ),
                    ),
                    const SizedBox(height: 8),
                    Row(
                      mainAxisSize: MainAxisSize.min,
                      mainAxisAlignment: MainAxisAlignment.start,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Text(
                          'EXP: ${formatExpiryDate(cardExpiry)}',
                          style: const TextStyle(
                            color: Colors.white,
                            fontSize: 12,
                            fontWeight: FontWeight.w400,
                          ),
                        ),
                        const SizedBox(width: 16),
                        Text(
                          'CVV: ${formatCVV(cardCVV)}',
                          style: const TextStyle(
                            color: Colors.white,
                            fontSize: 12,
                            fontWeight: FontWeight.w400,
                          ),
                        ),
                      ],
                    ),
                  ],
                ),
                const SizedBox(height: 10),
                Text(
                  cardName.toUpperCase(),
                  style: const TextStyle(
                    color: Colors.white,
                    fontSize: 14,
                    fontWeight: FontWeight.w400,
                  ),
                ),
              ],
            ),
          ),
          const Positioned(
            left: 17,
            top: 65,
            child: SizedBox(
              width: 44.30,
              height: 40,
              child: Image(image: AssetImage("assets/images/sim.png")),
            ),
          ),
          const Positioned(
              left: 17,
              top: 24,
              child: Image(image: AssetImage("assets/images/renapay.png")))
        ],
      ),
    );
  }
}
